@@ -1,7 +1,7 @@
 package Perinci::CmdLine::dux;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '1.50'; # VERSION
+our $DATE = '2015-11-22'; # DATE
+our $VERSION = '1.51'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -84,6 +84,8 @@ sub hook_format_result {
 }
 
 sub hook_display_result {
+    no warnings 'uninitialized';
+
     my ($self, $r) = @_;
 
     my $res = $r->{res};
@@ -111,7 +113,7 @@ Perinci::CmdLine::dux - Perinci::CmdLine subclass for dux cli
 
 =head1 VERSION
 
-This document describes version 1.50 of Perinci::CmdLine::dux (from Perl distribution App-dux), released on 2015-08-17.
+This document describes version 1.51 of Perinci::CmdLine::dux (from Perl distribution App-dux), released on 2015-11-22.
 
 =head1 DESCRIPTION
 
@@ -133,7 +135,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-dux>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-dux>.
+Source repository is at L<https://github.com/sharyanto/perl-App-dux>.
 
 =head1 BUGS
 
